@@ -137,8 +137,10 @@ class RDBService:
 
 
     def __toValue(self, var):
-        if isinstance(var, int) or isinstance(var, float) or isinstance(var,Decimal):
-            return var
+        if isinstance(var, int) or isinstance(var, float):
+            return str(var)
+        elif isinstance(var,Decimal):
+            return str(round(var),2)
         else:
             return '\'{}\''.format(var)
 
